==> tuia-advert-center-api-1.5.9-20180808.130850-27-sources.jar: cn/com/duiba/tuia/core/api/dto/req/solt/SlotInfoCenterReq.java <==
package cn.com.duiba.tuia.core.api.dto.req.solt;

/** 查询广告位信息请求实体－主要针对查询查询屏蔽标签
 * Created by jzl on 18/4/17.
 */
public class SlotInfoCenterReq {
    //无屏蔽
    public static final int NO_SHIELD = 0;
    //行业屏蔽
    public static final int INDUSTRY_SHIELD = 1;
    //标签屏蔽
    public static final int TAG_SHIELD = 2;
    //活动屏蔽
    public static final int ACTIVITY_SHIELD = 3;
    //落地页屏蔽屏蔽
    public static final int LAND_URL_SHIELD = 4;

    //删除状态
    public static final int DELETE_STATUS = 0;
    //关闭状态
    public static final int CLOSE_STATUS = 1;
    //冻结状态
    public static final int FREEZE_STATUS = 2;
    //开启状态
    public static final int ENABLE_STATUS = 3;

    /**
     * 广告位ID
     */
    private Long slotId;
    /**
     * 媒体id
     */
    private Long appId;

    /**
     * 发券量
     */
    private Long launchCount;

    /**
     * 广告位名称
     */
    private String slotName;


    private Integer status;

    private Integer type;

    private String shieldContent;

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getLaunchCount() {
        return launchCount;
    }

    public void setLaunchCount(Long launchCount) {
        this.launchCount = launchCount;
    }


    public String getSlotName() {
        return slotName;
    }

    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getShieldContent() {
        return shieldContent;
    }

    public void setShieldContent(String shieldContent) {
        this.shieldContent = shieldContent;
    }

    @Override
    public String toString() {
        return org.apache.commons.lang.builder.ToStringBuilder.reflectionToString(this);
    }
}

==> tuia-advert-center-api-2.0.6-sources.jar: cn/com/duiba/tuia/core/api/dto/req/solt/SlotInfoCenterReq.java <==
package cn.com.duiba.tuia.core.api.dto.req.solt;

import java.io.Serializable;

/** 查询广告位信息请求实体－主要针对查询查询屏蔽标签
 * Created by jzl on 18/4/17.
 */
public class SlotInfoCenterReq  implements Serializable {
    //无屏蔽
    public static final int NO_SHIELD = 0;
    //行业屏蔽
    public static final int INDUSTRY_SHIELD = 1;
    //标签屏蔽
    public static final int TAG_SHIELD = 2;
    //活动屏蔽
    public static final int ACTIVITY_SHIELD = 3;
    //落地页屏蔽屏蔽
    public static final int LAND_URL_SHIELD = 4;

    //删除状态
    public static final int DELETE_STATUS = 0;
    //关闭状态
    public static final int CLOSE_STATUS = 1;
    //冻结状态
    public static final int FREEZE_STATUS = 2;
    //开启状态
    public static final int ENABLE_STATUS = 3;
    private static final long serialVersionUID = 9138630035021030215L;

    /**
     * 广告位ID
     */
    private Long slotId;
    /**
     * 媒体id
     */
    private Long appId;

    /**
     * 发券量
     */
    private Long launchCount;

    /**
     * 广告位名称
     */
    private String slotName;


    private Integer status;

    private Integer type;

    private String shieldContent;

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getLaunchCount() {
        return launchCount;
    }

    public void setLaunchCount(Long launchCount) {
        this.launchCount = launchCount;
    }


    public String getSlotName() {
        return slotName;
    }

    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getShieldContent() {
        return shieldContent;
    }

    public void setShieldContent(String shieldContent) {
        this.shieldContent = shieldContent;
    }

    @Override
    public String toString() {
        return org.apache.commons.lang.builder.ToStringBuilder.reflectionToString(this);
    }
}
